<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * For example, it puts together the home page when no home.php file exists.
 *
 * Learn more: http://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage 10070619-047
 * @since 10070619-047
 */

get_header(); ?>
<div id="content">
		<div id="sidebar">
			<?php if ( have_posts() ) : ?>

			<?php /* Start the Loop */ ?>
			<?php while ( have_posts() ) : the_post(); ?>
				<?php get_template_part( 'content', get_post_format() ); ?>
			<?php endwhile; ?>

			<?php twentytwelve_content_nav( 'nav-below' ); ?>

		<?php else : ?>

			<article id="post-0" class="post no-results not-found">

			<?php if ( current_user_can( 'edit_posts' ) ) :
				// Show a different message to a logged-in user who can add posts.
			?>
				<header class="entry-header">
					<h1 class="entry-title"><?php _e( 'No posts to display', 'twentytwelve' ); ?></h1>
				</header>

				<div class="entry-content">
					<p><?php printf( __( 'Ready to publish your first post? <a href="%s">Get started here</a>.', 'twentytwelve' ), admin_url( 'post-new.php' ) ); ?></p>
				</div><!-- .entry-content -->

			<?php else :
				// Show the default message to everyone else.
			?>
				<header class="entry-header">
					<h1 class="entry-title"><?php _e( 'Nothing Found', 'twentytwelve' ); ?></h1>
				</header>

				<div class="entry-content">
					<p><?php _e( 'Apologies, but no results were found. Perhaps searching will help find a related post.', 'twentytwelve' ); ?></p>
					<?php get_search_form(); ?>
				</div><!-- .entry-content -->
			<?php endif; // end current_user_can() check ?>

			</article><!-- #post-0 -->

		<?php endif; // end have_posts() check ?>



<div class="container content container-fluid" id="home">



	<!-- HOME -->
	<div class="row-fluid">
  
		<!-- PHONES IMAGE FOR DESKTOP MEDIA QUERY -->
		<div class="span5 visible-desktop">
			<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/phones.png">
		</div>
	
		<!-- APP DETAILS -->
		<div class="span7">
	
			<!-- ICON -->
			<div class="visible-desktop" id="icon">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/app_icon.png" />
			</div>
			
			<!-- APP NAME -->
			<div id="app-name">
				<h1>FlexApp</h1>
			</div>
			
			<!-- VERSION -->
			<div id="version">
				<span class="version-top label label-inverse">Version 1.0</span>
			</div>
            
			<!-- TAGLINE -->
			<div id="tagline">
				A Free Responsive Website Template for Your Mobile App
			</div>
		
			<!-- PHONES IMAGE FOR TABLET MEDIA QUERY -->
			<div class="hidden-desktop" id="phones">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/phones.png">
			</div>
            
			<!-- DESCRIPTION -->
			<div id="description">
				FlexApp is a free, fully responsive website template for marketing your mobile application. The design uses CSS3 to scale the content proportionally to whatever device is being used. Give it a try by resizing your browser!
			</div>
            
			<!-- FEATURES -->
			<ul id="features">
				<li>Fully Responsive HTML/CSS3 Template</li>
				<li>Built on Bootstrap by Twitter</li>
				<li>Images and Photoshop Files Included</li>
				<li>Completely Free!</li>
			</ul>
		
			<!-- DOWNLOAD & REQUIREMENT BOX -->
			<div class="download-box">
				<a href="#"><img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/available-on-the-app-store.png"></a>
			</div>
			<div class="download-box">
				<a href="#"><img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/android_app_on_play_logo_large.png"></a>
			</div>
			<div class="download-box">
				<strong>Requirements:</strong><br>
				Compatible with iPhone and iPod touch. Requires iPhone OS 2.2 or later. WiFi, Edge, or 3G network connection sometimes required.
			</div>
			<div class="download-box">
				<strong>Requirements:</strong><br>
				Requires Android 2.3 and higher. WiFi, Edge, or 3G network connection sometimes required.
			</div>
			
		</div>
	</div>
	
	
	
	<!-- ABOUT & UPDATES -->
	<div class="row-fluid" id="about">
	
		<div class="span6">
			<h2 class="page-title" id="scroll_up">
				About
				<a href="#home" class="arrow-top">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/arrow-top.png">
				</a>
			</h2>
			
			<p>FlexApp is a fully responsive HTML/CSS template perfect for marketing your mobile application. The template utilizes responsive CSS3 & jQuery technology to provide a consistent and enjoyable viewing experience across multiple devices.</p>
			<p>FlexApp is 100% free to use. You may change, edit or modify the template however you wish, for free or commercial projects.</p> 
			<p><span xmlns:dct="http://purl.org/dc/terms/" property="dct:title">FlexApp</span> by <a xmlns:cc="http://creativecommons.org/ns#" href="http://www.trippoinc.com" property="cc:attributionName" rel="cc:attributionURL">Trippo</a> is licensed under <a rel="license" href="http://creativecommons.org/licenses/by/3.0/">CC BY 3.0</a>.<br />Built on <a xmlns:dct="http://purl.org/dc/terms/" href="http://twitter.github.com/bootstrap/" rel="dct:source">Bootstrap</a>.</p>
			
		</div>
	
		<div class="span6 updates" id="updates">
			<h2 class="page-title" id="scroll_up">
				Updates
				<a href="#home" class="arrow-top">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/arrow-top.png">
				</a>
			</h2>
			
			<!-- UPDATES & RELEASE NOTES -->
			
			<h3 class="version">Version 1.2</h3>
			<span class="release-date">Released on April 28th, 2012</span>
			<ul>
				<li><span class="label new">NEW</span>Challenge a Friend</li>
				<li><span class="label fix">FIX</span>Fixed 'Resume Game' Bug</li>
			</ul>
			<hr>
			
			<h3 class="version">Version 1.1</h3>
			<span class="release-date">Released on January 28th, 2012</span>
			<ul>
				<li><span class="label new">NEW</span>Facebook & Twitter Integration</li>
				<li><span class="label fix">FIX</span>Various Bug Fixes</li>
				<li><span class="label new">NEW</span>Graphics for Retina Display</li>
			</ul>
			<hr>
		
			<h3 class="version">Version 1.0</h3>
			<span class="release-date">Released on January 10th, 2012</span>
			<ul>
				<li><span class="label label-info">NEW</span>Initial Release</li>
			</ul>
			
		</div>
	
	</div>
	
	
	
	<!-- SCREENSHOTS -->
	<div class="row-fluid" id="screenshots">
		
		<h2 class="page-title" id="scroll_up">
				Screenshots
				<a href="#home" class="arrow-top">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/arrow-top.png">
				</a>
			</h2>
		
		<!-- SCREENSHOT IMAGES ROW 1-->
		<ul class="thumbnails">
			<li class="span3">
				<a href="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" rel="gallery" class="thumbnail">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" alt="">
				</a>
			</li>
		
			<li class="span3">
				<a href="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" rel="gallery" class="thumbnail">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" alt="">
				</a>
			</li>
			
			<li class="span3">
				<a href="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" rel="gallery" class="thumbnail">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" alt="">
				</a>
			</li>
 
			<li class="span3">
				<a href="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" rel="gallery" class="thumbnail">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" alt="">
				</a>
			</li>
		</ul>	
		
		<!-- SCREENSHOT IMAGES ROW 2-->		
		<ul class="thumbnails">
			<li class="span3">
				<a href="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" rel="gallery" class="thumbnail">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" alt="">
				</a>
			</li>
			
			<li class="span3">
				<a href="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" rel="gallery" class="thumbnail">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" alt="">
				</a>
			</li>
			
			<li class="span3">
				<a href="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" rel="gallery" class="thumbnail">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" alt="">
				</a>
			</li>
			
			<li class="span3">
				<a href="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" rel="gallery" class="thumbnail">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/screenshot.jpg" alt="">
				</a>
			</li>
		</ul>
	</div>
	
	
	
	<!-- CONTACT -->
	<div class="row-fluid" id="contact">
	
		<h2 class="page-title" id="scroll_up">
				Contact
				<a href="#home" class="arrow-top">
				<img src="<?php get_template_directory_uri( 'template_url' ); ?>/img/arrow-top.png">
				</a>
			</h2>
		
		<!-- CONTACT INFO -->
		<div class="span4" id="contact-info">
			<h3>Contact Us</h3>
			<p>FlexApp is free and thus unfortunately we cannot provide basic support for it. We simply don't have the time to answer everyone's questions.</p>
			<p>However, you may contact us about general business inquiries or to report bugs in the template!<p>
			<p><a href="mailto:contact@trippoinc.com">contact@trippoinc.com</a></p>
		</div>
		
		
<?php get_sidebar(); ?>
<?php get_footer();?>